@@ -8,6 +8,8 @@ class FiberData(InternetData):
         self.previous_contract_pon = args.get("previous_contract_pon", "")
         self.previous_contract_fiber_speed = args.get("previous_contract_fiber_speed", "")
         self.activation_notes = args.get("activation_notes", "")
-        for key in ["previous_contract_pon", "previous_contract_fiber_speed", "activation_notes"]:
+        self.all_grouped_SIMS_recieved = args.get("all_grouped_SIMS_recieved")
+        for key in ["previous_contract_pon", "previous_contract_fiber_speed",
+                    "activation_notes", "all_grouped_SIMS_recieved"]:
             args.pop(key, None)
         super().__init__(**args)
