@@ -14,6 +14,7 @@ class FiberDynamicFields(InternetDynamicFields):
             self._df_previous_contract_fiber_speed(),
             self._activation_notes(),
             self._df_mobile_pack_contracts(),
+            self._all_grouped_SIMS_recieved(),
         ]
 
     def _activation_notes(self):
@@ -33,3 +34,10 @@ class FiberDynamicFields(InternetDynamicFields):
             name="OdooMobileContractRefRelacionats",
             value=self.service_data.mobile_pack_contracts,
         )
+
+    def _all_grouped_SIMS_recieved(self):
+        are_all_grouped_SIMS_recieved = "1" if self.service_data.all_grouped_SIMS_recieved else "0"
+        return DynamicField(
+            name="SIMrebuda",
+            value=are_all_grouped_SIMS_recieved,
+        )
