@@ -5,8 +5,9 @@ class MobileData:
         self, order_id, phone_number, iban, email, sc_icc, icc,
         has_sim, type, previous_owner_vat, previous_owner_name,
         previous_owner_surname, previous_provider, product, delivery_street,
-        delivery_city, delivery_zip_code, delivery_state, activation_notes="",
-        notes="", is_grouped_with_fiber=False
+        delivery_city, delivery_zip_code, delivery_state, technology,
+        activation_notes="", notes="", is_grouped_with_fiber=False,
+        fiber_linked="",
     ):
         self.order_id = order_id
         self.phone_number = phone_number
@@ -25,6 +26,8 @@ class MobileData:
         self.delivery_city = delivery_city
         self.delivery_zip_code = delivery_zip_code
         self.delivery_state = delivery_state
+        self.technology = technology
         self.activation_notes = activation_notes
         self.notes = notes
         self.is_grouped_with_fiber = is_grouped_with_fiber
+        self.fiber_linked = fiber_linked
