@@ -25,6 +25,9 @@ class ProvisionDynamicFields():
             self._previous_owner_surname1(),
             self._previous_owner_full_name(),
             self._product(),
+            self._service_technology(),
+            self._has_active_contracts(),
+            self._lang(),
         ]
         dynamic_fields += self._build_specific_dynamic_fields()
 
@@ -48,6 +51,19 @@ class ProvisionDynamicFields():
     def _vat_number(self):
         return DynamicField(name="NIFNIESoci", value=self.customer_data.vat_number)
 
+    def _has_active_contracts(self):
+        has_active_contacts = "1" if self.customer_data.has_active_contracts else "0"
+        return DynamicField(
+            name="teContractesActius",
+            value=has_active_contacts
+        )
+
+    def _lang(self):
+        return DynamicField(
+            name="idioma",
+            value=self.customer_data.language
+        )
+
     def _mail(self):
         return DynamicField(name="correuElectronic", value=self.service_data.email)
 
@@ -77,3 +93,9 @@ class ProvisionDynamicFields():
             name="nomCognomSociAntic",
             value=full_name
         )
+
+    def _service_technology(self):
+        return DynamicField(
+            name="TecDelServei",
+            value=self.service_data.technology
+        )
