@@ -1,7 +1,7 @@
 # coding: utf-8
 from otrs_somconnexio.otrs_models.provision_ticket import ProvisionTicket
 from otrs_somconnexio.otrs_models.router_4G_dynamic_fields import Router4GDynamicFields
-from otrs_somconnexio.otrs_models.configurations.router_4G_ticket import Router4GTicketConfiguration
+from otrs_somconnexio.otrs_models.configurations.provision.router_4G_ticket import Router4GTicketConfiguration
 
 
 class Router4GTicket(ProvisionTicket):
