@@ -24,7 +24,10 @@ class TicketFactory(object):
             TicketClass = FiberTicket
         elif self.service_data.service_type == 'mobile':
             if (self.service_data.is_grouped_with_fiber
-                    and self.service_data.type == "portability"):
+                    and (
+                        self.service_data.type == 'portability'
+                        or self.service_data.product == 'SE_SC_REC_MOBILE_PACK_UNL_20480'
+                    )):
                 TicketClass = MobilePausedTicket
             else:
                 TicketClass = MobileTicket
