@@ -1,10 +1,10 @@
 # coding: utf-8
 from pyotrs.lib import DynamicField
 
-from otrs_somconnexio.client import OTRSClient
+from .update_ticket_DF import UpdateTicketDF
 
 
-class UnblockMobilePackTicket:
+class UnblockMobilePackTicket(UpdateTicketDF):
     """
     Unblock the mobile pack tickets.
 
@@ -14,20 +14,8 @@ class UnblockMobilePackTicket:
     """
 
     def __init__(self, ticket_number, introduced_date):
-        self.ticket_number = ticket_number
         self.introduced_date = introduced_date
-
-    def run(self):
-        otrs_client = OTRSClient()
-        ticket = otrs_client.get_ticket_by_number(
-            self.ticket_number, dynamic_fields=True
-        )
-
-        otrs_client.update_ticket(
-            ticket.tid,
-            article=None,
-            dynamic_fields=self._prepare_dynamic_fields(ticket),
-        )
+        super().__init__(ticket_number)
 
     def _prepare_dynamic_fields(self, ticket):
         dynamic_fields = [
