@@ -33,17 +33,22 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'delivery_city',
             'delivery_zip_code',
             'delivery_state',
+            'technology',
+            'fiber_linked',
         ])
         customer_data = Mock(spec=[
             'id',
+            'phone',
             'first_name',
             'name',
             'vat_number',
-            'phone',
             'street',
             'city',
             'zip',
-            'subdivision'])
+            'subdivision',
+            'has_active_contracts',
+            'language',
+        ])
 
         mobile_data.service_type = 'mobile'
 
@@ -64,7 +69,8 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         self.assertIsInstance(ticket, MobileTicket)
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
-    def test_create_mobile_paused_ticket_factory(self, MockOTRSClient):
+    def test_create_mobile_portability_paused_ticket_factory(
+        self, MockOTRSClient):
         mobile_data = Mock(spec=[
             'order_id',
             'iban',
@@ -86,6 +92,69 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'delivery_city',
             'delivery_zip_code',
             'delivery_state',
+            'technology',
+            'fiber_linked',
+        ])
+        customer_data = Mock(spec=[
+            'id',
+            'phone',
+            'first_name',
+            'name',
+            'vat_number',
+            'street',
+            'city',
+            'zip',
+            'subdivision',
+            'has_active_contracts',
+            'language',
+        ])
+
+        mobile_data.service_type = 'mobile'
+        mobile_data.type = "portability"
+        mobile_data.is_grouped_with_fiber = True
+
+        otrs_process_ticket = Mock(spec=['id'])
+        otrs_process_ticket.id = 234
+
+        mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
+        mock_otrs_client.create_otrs_process_ticket.return_value = otrs_process_ticket
+        MockOTRSClient.return_value = mock_otrs_client
+
+        ticket = TicketFactory(
+            service_data=mobile_data,
+            customer_data=customer_data,
+        ).build()
+        ticket.create()
+
+        self.assertEquals(ticket.id, 234)
+        self.assertIsInstance(ticket, MobilePausedTicket)
+
+    @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
+    def test_create_mobile_pack_product_paused_ticket_factory(
+        self, MockOTRSClient):
+        mobile_data = Mock(spec=[
+            'order_id',
+            'iban',
+            'email',
+            'phone_number',
+            'sc_icc',
+            'icc',
+            'type',
+            'previous_provider',
+            'previous_owner_name',
+            'previous_owner_surname',
+            'previous_owner_vat',
+            'product',
+            'notes',
+            'has_sim',
+            'is_grouped_with_fiber',
+            'activation_notes',
+            'delivery_street',
+            'delivery_city',
+            'delivery_zip_code',
+            'delivery_state',
+            'technology',
+            'fiber_linked',
         ])
         customer_data = Mock(spec=[
             'id',
@@ -96,10 +165,12 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'street',
             'city',
             'zip',
-            'subdivision'])
+            'subdivision',
+            'has_active_contracts',
+            'language'])
 
         mobile_data.service_type = 'mobile'
-        mobile_data.type = "portability"
+        mobile_data.product = 'SE_SC_REC_MOBILE_PACK_UNL_20480'
         mobile_data.is_grouped_with_fiber = True
 
         otrs_process_ticket = Mock(spec=['id'])
@@ -151,8 +222,22 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'landline_phone_number',
             'product',
             'previous_internal_provider',
+            'technology',
+            'fiber_linked',
+        ])
+        customer_data = Mock(spec=[
+            'id',
+            'phone',
+            'first_name',
+            'name',
+            'vat_number',
+            'street',
+            'city',
+            'zip',
+            'subdivision',
+            'has_active_contracts',
+            'language',
         ])
-        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
         service_data.service_type = 'adsl'
 
@@ -210,10 +295,15 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
                 "product",
                 "previous_internal_provider",
                 "mobile_pack_contracts",
+                "all_grouped_SIMS_recieved",
+                "technology",
+                "fiber_linked",
             ]
         )
-        customer_data = Mock(spec=["id", "first_name", "name", "vat_number", "phone"])
-
+        customer_data = Mock(spec=[
+            'id', 'first_name', 'name', 'vat_number',
+            'phone', 'has_active_contracts', 'language'
+        ])
         service_data.service_type = 'fiber'
 
         otrs_process_ticket = Mock(spec=['id'])
