@@ -34,7 +34,8 @@ class ADSLDataTestCase(unittest.TestCase):
             orange_fiber_coverage=None,
             type="location_change",
             landline_phone_number="landline_phone_number",
-            product="product"
+            product="product",
+            technology="ADSL",
         )
 
         self.assertIsInstance(adsl_data, ADSLData)
