@@ -11,10 +11,9 @@ class ADSLTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
     def test_build_ticket(self, MockTicket):
         customer_data = Mock(spec=['id'])
-        service_data = Mock(spec=['order_id'])
-
+        service_data = Mock(spec=['order_id', 'technology'])
         expected_ticket_arguments = {
-            "Title": "Sol·licitud adsl {}".format(service_data.order_id),
+            "Title": "Ticket#{} - Només ADSL".format(service_data.order_id),
             "Type": ADSLTicketConfiguration.type,
             "Queue": ADSLTicketConfiguration.queue,
             "State": ADSLTicketConfiguration.state,
@@ -31,15 +30,16 @@ class ADSLTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockInternetArticle):
         customer_data = Mock(spec=[])
-        service_data = Mock(spec=['order_id', 'notes'])
+        service_data = Mock(spec=['order_id', 'notes', 'technology'])
 
         mock_mobile_article = MockInternetArticle.return_value
 
         ADSLTicket(service_data, customer_data)._build_article()
 
         MockInternetArticle.assert_called_with(
-            'adsl', 
-            service_data.order_id, 
+            service_data.technology,
+            service_data.order_id,
+            'adsl',
             service_data.notes
         )
         mock_mobile_article.call.assert_called_once()
@@ -69,6 +69,8 @@ class ADSLTicketTestCase(unittest.TestCase):
             'first_name',
             'name',
             'vat_number',
+            'has_active_contracts',
+            'language',
         ])
         service_data = Mock(spec=[
             'order_id',
@@ -100,6 +102,7 @@ class ADSLTicketTestCase(unittest.TestCase):
             'landline_phone_number',
             'product',
             'previous_internal_provider',
+            'technology',
         ])
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
