@@ -24,6 +24,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
                 "name",
                 "vat_number",
                 "phone",
+                "has_active_contracts",
+                "language"
             ]
         )
         self.service_data = Mock(
@@ -60,6 +62,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
                 "product",
                 "previous_internal_provider",
                 "mobile_pack_contracts",
+                "all_grouped_SIMS_recieved",
+                "technology"
             ]
         )
 
@@ -203,6 +207,45 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["NIFNIESoci"], "NIFCode")
 
+    def test_has_active_contracts_field(self):
+        self.customer_data.has_active_contracts = True
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "1")
+
+    def test_has_active_contracts_false_field(self):
+        self.customer_data.has_active_contracts = False
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "0")
+
+    def test_language_field(self):
+        self.customer_data.language = "ca_ES"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["idioma"], "ca_ES")
+
     def test_IBAN_field(self):
         self.service_data.iban = "ES6621000418401234567891"
 
@@ -590,3 +633,42 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             dynamic_fields_dct["OdooMobileContractRefRelacionats"],
             self.service_data.mobile_pack_contracts,
         )
+
+    def test_all_grouped_SIMS_recieved_field(self):
+        self.service_data.all_grouped_SIMS_recieved = True
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["SIMrebuda"], "1")
+
+    def test_not_all_grouped_SIMS_recieved_field(self):
+        self.service_data.all_grouped_SIMS_recieved = False
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["SIMrebuda"], "0")
+
+    def test_tecnhology(self):
+        self.service_data.technology = "Fibra"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["TecDelServei"], "Fibra")
