@@ -11,10 +11,30 @@ class FiberTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
     def test_build_ticket(self, MockTicket):
         customer_data = Mock(spec=['id'])
-        service_data = Mock(spec=['order_id'])
+        service_data = Mock(spec=['order_id', 'technology'])
 
         expected_ticket_arguments = {
-            "Title": "Sol·licitud fiber {}".format(service_data.order_id),
+            "Title": "Ticket#{} - Només fibra".format(service_data.order_id),
+            "Type": FiberTicketConfiguration.type,
+            "Queue": FiberTicketConfiguration.queue,
+            "State": FiberTicketConfiguration.state,
+            "SLA": FiberTicketConfiguration.SLA,
+            "Service": FiberTicketConfiguration.service,
+            "Priority": FiberTicketConfiguration.priority,
+            "CustomerUser": customer_data.id,
+            "CustomerID": customer_data.id,
+        }
+
+        FiberTicket(service_data, customer_data)._build_ticket()
+        MockTicket.assert_called_with(expected_ticket_arguments)
+
+    @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
+    def test_build_ticket_mixed(self, MockTicket):
+        customer_data = Mock(spec=['id'])
+        service_data = Mock(spec=['order_id', 'technology'])
+        service_data.technology = 'Mixta'
+        expected_ticket_arguments = {
+            "Title": "Ticket#{} - Fibra mixta".format(service_data.order_id),
             "Type": FiberTicketConfiguration.type,
             "Queue": FiberTicketConfiguration.queue,
             "State": FiberTicketConfiguration.state,
@@ -31,15 +51,16 @@ class FiberTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockInternetArticle):
         customer_data = Mock(spec=[])
-        service_data = Mock(spec=['order_id','notes'])
+        service_data = Mock(spec=['order_id','notes', 'technology'])
 
         mock_mobile_article = MockInternetArticle.return_value
 
         FiberTicket(service_data, customer_data)._build_article()
 
         MockInternetArticle.assert_called_with(
-            'fiber',
+            service_data.technology,
             service_data.order_id,
+            'fiber',
             service_data.notes
         )
         mock_mobile_article.call.assert_called_once()
@@ -70,6 +91,8 @@ class FiberTicketTestCase(unittest.TestCase):
                 "first_name",
                 "name",
                 "vat_number",
+                "has_active_contracts",
+                "language",
             ]
         )
         service_data = Mock(
@@ -106,6 +129,8 @@ class FiberTicketTestCase(unittest.TestCase):
                 "product",
                 "previous_internal_provider",
                 "mobile_pack_contracts",
+                "all_grouped_SIMS_recieved",
+                "technology",
             ]
         )
 
