@@ -28,6 +28,8 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'zip',
             'city',
             'subdivision',
+            'has_active_contracts',
+            'language'
         ])
         self.mobile_data = Mock(spec=[
             'order_id',
@@ -50,6 +52,8 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'delivery_zip_code',
             'delivery_state',
             'activation_notes',
+            'technology',
+            'fiber_linked',
         ])
         self.mobile_data.type = 'new'
 
@@ -117,6 +121,45 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["NIFNIESoci"], "NIFCode")
 
+    def test_has_active_contracts_field(self):
+        self.customer_data.has_active_contracts = True
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "1")
+
+    def test_has_active_contracts_false_field(self):
+        self.customer_data.has_active_contracts = False
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "0")
+
+    def test_language_field(self):
+        self.customer_data.language = "ca_ES"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["idioma"], "ca_ES")
+
     def test_order_id_field(self):
         self.mobile_data.order_id = '2222'
 
@@ -455,4 +498,30 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["consideracionsActivacio"], "text text text")
\ No newline at end of file
+        self.assertEqual(dynamic_fields_dct["consideracionsActivacio"], "text text text")
+
+    def test_tecnhology(self):
+        self.mobile_data.technology = "Mòbil"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["TecDelServei"], "Mòbil")
+
+    def test_fiber_linked(self):
+        self.mobile_data.fiber_linked = "72"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["OdooContractRefRelacionat"], "72")
