@@ -12,14 +12,14 @@ class MobileTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
     def test_build_ticket(self, MockTicket):
         mobile_data = Mock(spec=[
-            'order_id'
+            'order_id', 'technology'
         ])
         mobile_data.order_id = 123
 
         customer_data = Mock(spec=['id'])
 
         expected_ticket_arguments = {
-            "Title": "Sol·licitud mobile {}".format(mobile_data.order_id),
+            "Title": "Ticket#{} - Només mòbil".format(mobile_data.order_id),
             "Type": MobileTicketConfiguration.type,
             "Queue": MobileTicketConfiguration.queue,
             "State": MobileTicketConfiguration.state,
@@ -37,7 +37,7 @@ class MobileTicketTestCase(unittest.TestCase):
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockProvisionArticle):
-        mobile_data = Mock(spec=['order_id', 'notes'])
+        mobile_data = Mock(spec=['order_id', 'notes', 'technology'])
         mobile_data.order_id = 123
         mobile_data.notes = "Hola mundo"
 
@@ -48,8 +48,9 @@ class MobileTicketTestCase(unittest.TestCase):
         MobileTicket(mobile_data, customer_data)._build_article()
 
         MockProvisionArticle.assert_called_with(
-            'mobile',
+            mobile_data.technology,
             mobile_data.order_id,
+            'mobile',
             mobile_data.notes
         )
         mock_mobile_article.call.assert_called_once()
@@ -94,6 +95,8 @@ class MobileTicketTestCase(unittest.TestCase):
             'delivery_city',
             'delivery_zip_code',
             'delivery_state',
+            'technology',
+            'fiber_linked',
         ])
         mobile_data.order_id = 4321
         mobile_data.type = 'new'
@@ -108,6 +111,8 @@ class MobileTicketTestCase(unittest.TestCase):
             'city',
             'zip',
             'subdivision',
+            'has_active_contracts',
+            'language',
         ])
         customer_data.id = 1234
 
