@@ -9,12 +9,14 @@ from otrs_somconnexio.exceptions import ServiceTypeNotAllowedError
 class TicketFactoryTestCase(unittest.TestCase):
     def setUp(self):
         self.customer_data = Mock(spec=[])
-        self.service_data = Mock(spec=['order_id', 'type', 'is_pack'])
+        self.service_data = Mock(
+            spec=['order_id', 'type', 'is_grouped_with_fiber']
+        )
 
     @patch('otrs_somconnexio.otrs_models.ticket_factory.MobileTicket')
     def test_build_mobile_ticket(self, MockMobileTicket):
         self.service_data.service_type = 'mobile'
-        self.service_data.is_pack = False
+        self.service_data.is_grouped_with_fiber = False
 
         TicketFactory(self.service_data, self.customer_data).build()
 
@@ -26,7 +28,8 @@ class TicketFactoryTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.ticket_factory.MobilePausedTicket')
     def test_build_mobile_paused_ticket(self, MockMobilePausedTicket):
         self.service_data.service_type = 'mobile'
-        self.service_data.is_pack = True
+        self.service_data.type = 'portability'
+        self.service_data.is_grouped_with_fiber = True
 
         TicketFactory(self.service_data, self.customer_data).build()
 
